@@ -1,7 +1,6 @@
 """Bridge: Init"""
 from __future__ import annotations
 from aiohttp import ClientResponse
-from datetime import datetime, timezone
 from typing import Any, List
 
 from .client import BridgeClient
@@ -19,16 +18,16 @@ from .objects.display.put import DisplayPutPayload
 from .objects.events import Event, EventBase
 from .objects.filesystem import Filesystem
 from .objects.graphics import Graphics
-from .objects.media import Media, Source
-from .objects.media.delete import MediaDeleteResponse
-from .objects.media.post import MediaPostPayload, MediaPostResponse
-from .objects.media.put import MediaPutPayload, MediaPutResponse
+from .objects.information import Information
+from .objects.keyboard.payload import KeyboardPayload
+from .objects.keyboard.response import KeyboardResponse
 from .objects.memory import Memory
 from .objects.network import Network
 from .objects.open.payload import OpenPayload
 from .objects.os import Os
-from .objects.processes import Processes
+from .objects.processes import ProcessList, Processes
 from .objects.settings import Settings
+from .objects.settings.put import SettingsPutPayload
 from .objects.system import System
 
 BASE_HEADERS = {"Accept": "application/json"}
@@ -38,7 +37,7 @@ class Bridge(BridgeBase):
     """Main class for Bridge."""
 
     def __init__(self, client: BridgeClient, base_url: str, api_key: str) -> None:
-        """Initialize the token manager class."""
+        """Initialize the class."""
         self._client = client
         self._base_url = base_url
         self._api_key = api_key
@@ -49,10 +48,7 @@ class Bridge(BridgeBase):
         self._display: Display = {}
         self._filesystem: Filesystem = {}
         self._graphics: Graphics = {}
-        self._media_cover: str | None = None
-        self._media_status_last_updated: datetime | None = None
-        self._media_status: Media | None = None
-        self._media: Media = {}
+        self._information: Information = {}
         self._memory: Memory = {}
         self._network: Network = {}
         self._os: Os = {}
@@ -69,6 +65,10 @@ class Bridge(BridgeBase):
     def battery(self) -> Battery:
         return self._battery
 
+    @property
+    def base_url(self) -> str:
+        return self._base_url
+
     @property
     def bluetooth(self) -> Bluetooth:
         return self._bluetooth
@@ -90,24 +90,8 @@ class Bridge(BridgeBase):
         return self._graphics
 
     @property
-    def media_cover(self) -> str | None:
-        return self._media_cover
-
-    @property
-    def media_source(self) -> Source:
-        return self._media_source
-
-    @property
-    def media_status(self) -> Media | None:
-        return self._media_status
-
-    @property
-    def media_status_last_updated(self) -> datetime:
-        return self._media_status_last_updated
-
-    @property
-    def media(self) -> Media:
-        return self._media
+    def information(self) -> Information:
+        return self._information
 
     @property
     def memory(self) -> Memory:
@@ -225,29 +209,10 @@ class Bridge(BridgeBase):
         self._graphics = Graphics(await self.async_get("/graphics"))
         return self._graphics
 
-    async def async_get_media(self) -> Media | None:
-        """Get media information"""
-        media = await self.async_get("/media")
-        if media is None:
-            return None
-        self._media = Media(media)
-        return self._media
-
-    async def async_get_media_cover(self) -> Media | None:
-        """Get media cover"""
-        cover = await self.async_get("/media/cover")
-        if cover is None:
-            return None
-        self._media_cover = cover
-        return self._media_cover
-
-    async def async_get_media_source(self) -> Media | None:
-        """Get media cover"""
-        source = await self.async_get("/media/source")
-        if source is None:
-            return None
-        self._media_source = Source(source)
-        return self._media_source
+    async def async_get_information(self) -> Information:
+        """Get information"""
+        self._information = Information(await self.async_get("/information"))
+        return self._information
 
     async def async_get_memory(self) -> Memory:
         """Get memory information"""
@@ -273,6 +238,11 @@ class Bridge(BridgeBase):
         self._processes = Processes(await self.async_get("/processes"))
         return self._processes
 
+    async def async_get_process(self, name: str) -> Processes:
+        """Get process from name"""
+        self._processes = ProcessList(await self.async_get(f"/processes/{name}"))
+        return self._processes
+
     async def async_get_settings(self) -> List[Settings]:
         """Get settings"""
         settings = await self.async_get("/settings")
@@ -284,7 +254,7 @@ class Bridge(BridgeBase):
         return Settings(await self.async_get(f"/settings/{section}/{key}"))
 
     async def async_update_setting(
-        self, section: str, key: str, payload: MediaPutPayload
+        self, section: str, key: str, payload: SettingsPutPayload
     ) -> Settings:
         """Update setting"""
         return Settings(await self.async_put(f"/settings/{section}/{key}", payload))
@@ -294,21 +264,9 @@ class Bridge(BridgeBase):
         self._system = System(await self.async_get("/system"))
         return self._system
 
-    async def async_stop_media_player(self) -> MediaDeleteResponse:
-        """Stop media player"""
-        return MediaDeleteResponse(await self.async_delete("/media"))
-
-    async def async_create_media_player(
-        self, payload: MediaPostPayload
-    ) -> MediaPostResponse:
-        """Create media player"""
-        return MediaPostResponse(await self.async_post("/media", payload))
-
-    async def async_update_media(
-        self, id: str, payload: MediaPutPayload
-    ) -> MediaPutResponse:
-        """Update media player"""
-        return MediaPutResponse(await self.async_put(f"/media/{id}", payload))
+    async def async_send_keypress(self, payload: KeyboardPayload) -> KeyboardResponse:
+        """Send keypress"""
+        return KeyboardResponse(await self.async_post("/keyboard", payload))
 
     async def async_connect_websocket(self, host: str, port: int) -> None:
         self._websocket_client: BridgeClientWebSocket = BridgeClientWebSocket(
@@ -324,11 +282,6 @@ class Bridge(BridgeBase):
         async def handle_message(message: EventBase) -> None:
             if "data" in message and type(message["data"]) is dict:
                 event = Event(message["data"])
-                if event.name == "player-status":
-                    self._media_status = Media(event.data)
-                    self._media_status_last_updated = datetime.now(timezone.utc)
-                if event.name == "player-cover-ready":
-                    await self.async_get_media_cover()
                 await callback(event)
 
         await self._websocket_client.listen_for_messages(handle_message)
